# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetStreamPoolResult',
    'AwaitableGetStreamPoolResult',
    'get_stream_pool',
    'get_stream_pool_output',
]

@pulumi.output_type
class GetStreamPoolResult:
    """
    A collection of values returned by getStreamPool.
    """
    def __init__(__self__, compartment_id=None, custom_encryption_keys=None, defined_tags=None, endpoint_fqdn=None, freeform_tags=None, id=None, is_private=None, kafka_settings=None, lifecycle_state_details=None, name=None, private_endpoint_settings=None, state=None, stream_pool_id=None, time_created=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if custom_encryption_keys and not isinstance(custom_encryption_keys, list):
            raise TypeError("Expected argument 'custom_encryption_keys' to be a list")
        pulumi.set(__self__, "custom_encryption_keys", custom_encryption_keys)
        if defined_tags and not isinstance(defined_tags, dict):
            raise TypeError("Expected argument 'defined_tags' to be a dict")
        pulumi.set(__self__, "defined_tags", defined_tags)
        if endpoint_fqdn and not isinstance(endpoint_fqdn, str):
            raise TypeError("Expected argument 'endpoint_fqdn' to be a str")
        pulumi.set(__self__, "endpoint_fqdn", endpoint_fqdn)
        if freeform_tags and not isinstance(freeform_tags, dict):
            raise TypeError("Expected argument 'freeform_tags' to be a dict")
        pulumi.set(__self__, "freeform_tags", freeform_tags)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_private and not isinstance(is_private, bool):
            raise TypeError("Expected argument 'is_private' to be a bool")
        pulumi.set(__self__, "is_private", is_private)
        if kafka_settings and not isinstance(kafka_settings, list):
            raise TypeError("Expected argument 'kafka_settings' to be a list")
        pulumi.set(__self__, "kafka_settings", kafka_settings)
        if lifecycle_state_details and not isinstance(lifecycle_state_details, str):
            raise TypeError("Expected argument 'lifecycle_state_details' to be a str")
        pulumi.set(__self__, "lifecycle_state_details", lifecycle_state_details)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if private_endpoint_settings and not isinstance(private_endpoint_settings, list):
            raise TypeError("Expected argument 'private_endpoint_settings' to be a list")
        pulumi.set(__self__, "private_endpoint_settings", private_endpoint_settings)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if stream_pool_id and not isinstance(stream_pool_id, str):
            raise TypeError("Expected argument 'stream_pool_id' to be a str")
        pulumi.set(__self__, "stream_pool_id", stream_pool_id)
        if time_created and not isinstance(time_created, str):
            raise TypeError("Expected argument 'time_created' to be a str")
        pulumi.set(__self__, "time_created", time_created)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        Compartment OCID that the pool belongs to.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="customEncryptionKeys")
    def custom_encryption_keys(self) -> Sequence['outputs.GetStreamPoolCustomEncryptionKeyResult']:
        """
        Custom Encryption Key which will be used for encryption by all the streams in the pool.
        """
        return pulumi.get(self, "custom_encryption_keys")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Mapping[str, Any]:
        """
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations": {"CostCenter": "42"}}'
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter(name="endpointFqdn")
    def endpoint_fqdn(self) -> str:
        """
        The FQDN used to access the streams inside the stream pool (same FQDN as the messagesEndpoint attribute of a [Stream](https://docs.cloud.oracle.com/iaas/api/#/en/streaming/20180418/Stream) object). If the stream pool is private, the FQDN is customized and can only be accessed from inside the associated subnetId, otherwise the FQDN is publicly resolvable. Depending on which protocol you attempt to use, you need to either prepend https or append the Kafka port.
        """
        return pulumi.get(self, "endpoint_fqdn")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Mapping[str, Any]:
        """
        Free-form tags for this resource. Each tag is a simple key-value pair that is applied with no predefined name, type, or namespace. Exists for cross-compatibility only. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The OCID of the stream pool.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isPrivate")
    def is_private(self) -> bool:
        """
        True if the stream pool is private, false otherwise. The associated endpoint and subnetId of a private stream pool can be retrieved through the [GetStreamPool](https://docs.cloud.oracle.com/iaas/api/#/en/streaming/20180418/StreamPool/GetStreamPool) API.
        """
        return pulumi.get(self, "is_private")

    @property
    @pulumi.getter(name="kafkaSettings")
    def kafka_settings(self) -> Sequence['outputs.GetStreamPoolKafkaSettingResult']:
        """
        Settings for the Kafka compatibility layer.
        """
        return pulumi.get(self, "kafka_settings")

    @property
    @pulumi.getter(name="lifecycleStateDetails")
    def lifecycle_state_details(self) -> str:
        """
        Any additional details about the current state of the stream.
        """
        return pulumi.get(self, "lifecycle_state_details")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the stream pool.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="privateEndpointSettings")
    def private_endpoint_settings(self) -> Sequence['outputs.GetStreamPoolPrivateEndpointSettingResult']:
        """
        Optional settings if the stream pool is private.
        """
        return pulumi.get(self, "private_endpoint_settings")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The current state of the stream pool.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="streamPoolId")
    def stream_pool_id(self) -> str:
        return pulumi.get(self, "stream_pool_id")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        The date and time the stream pool was created, expressed in in [RFC 3339](https://tools.ietf.org/rfc/rfc3339) timestamp format.  Example: `2018-04-20T00:00:07.405Z`
        """
        return pulumi.get(self, "time_created")


class AwaitableGetStreamPoolResult(GetStreamPoolResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetStreamPoolResult(
            compartment_id=self.compartment_id,
            custom_encryption_keys=self.custom_encryption_keys,
            defined_tags=self.defined_tags,
            endpoint_fqdn=self.endpoint_fqdn,
            freeform_tags=self.freeform_tags,
            id=self.id,
            is_private=self.is_private,
            kafka_settings=self.kafka_settings,
            lifecycle_state_details=self.lifecycle_state_details,
            name=self.name,
            private_endpoint_settings=self.private_endpoint_settings,
            state=self.state,
            stream_pool_id=self.stream_pool_id,
            time_created=self.time_created)


def get_stream_pool(stream_pool_id: Optional[str] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetStreamPoolResult:
    """
    This data source provides details about a specific Stream Pool resource in Oracle Cloud Infrastructure Streaming service.

    Gets detailed information about the stream pool, such as Kafka settings.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_stream_pool = oci.Streaming.get_stream_pool(stream_pool_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str stream_pool_id: The OCID of the stream pool.
    """
    __args__ = dict()
    __args__['streamPoolId'] = stream_pool_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Streaming/getStreamPool:getStreamPool', __args__, opts=opts, typ=GetStreamPoolResult).value

    return AwaitableGetStreamPoolResult(
        compartment_id=__ret__.compartment_id,
        custom_encryption_keys=__ret__.custom_encryption_keys,
        defined_tags=__ret__.defined_tags,
        endpoint_fqdn=__ret__.endpoint_fqdn,
        freeform_tags=__ret__.freeform_tags,
        id=__ret__.id,
        is_private=__ret__.is_private,
        kafka_settings=__ret__.kafka_settings,
        lifecycle_state_details=__ret__.lifecycle_state_details,
        name=__ret__.name,
        private_endpoint_settings=__ret__.private_endpoint_settings,
        state=__ret__.state,
        stream_pool_id=__ret__.stream_pool_id,
        time_created=__ret__.time_created)


@_utilities.lift_output_func(get_stream_pool)
def get_stream_pool_output(stream_pool_id: Optional[pulumi.Input[str]] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetStreamPoolResult]:
    """
    This data source provides details about a specific Stream Pool resource in Oracle Cloud Infrastructure Streaming service.

    Gets detailed information about the stream pool, such as Kafka settings.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_stream_pool = oci.Streaming.get_stream_pool(stream_pool_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str stream_pool_id: The OCID of the stream pool.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['LogAnalyticsImportCustomContentArgs', 'LogAnalyticsImportCustomContent']

@pulumi.input_type
class LogAnalyticsImportCustomContentArgs:
    def __init__(__self__, *,
                 import_custom_content_file: pulumi.Input[str],
                 namespace: pulumi.Input[str],
                 expect: Optional[pulumi.Input[str]] = None,
                 is_overwrite: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a LogAnalyticsImportCustomContent resource.
        :param pulumi.Input[str] import_custom_content_file: Path to the file to upload which contains the custom content.
        :param pulumi.Input[str] namespace: The Logging Analytics namespace used for the request.
        :param pulumi.Input[str] expect: A value of `100-continue` requests preliminary verification of the request method, path, and headers before the request body is sent. If no error results from such verification, the server will send a 100 (Continue) interim response to indicate readiness for the request body. The only allowed value for this parameter is "100-Continue" (case-insensitive).
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[bool] is_overwrite: A flag indicating whether or not to overwrite existing content if a conflict is found during import content operation.
        """
        pulumi.set(__self__, "import_custom_content_file", import_custom_content_file)
        pulumi.set(__self__, "namespace", namespace)
        if expect is not None:
            pulumi.set(__self__, "expect", expect)
        if is_overwrite is not None:
            pulumi.set(__self__, "is_overwrite", is_overwrite)

    @property
    @pulumi.getter(name="importCustomContentFile")
    def import_custom_content_file(self) -> pulumi.Input[str]:
        """
        Path to the file to upload which contains the custom content.
        """
        return pulumi.get(self, "import_custom_content_file")

    @import_custom_content_file.setter
    def import_custom_content_file(self, value: pulumi.Input[str]):
        pulumi.set(self, "import_custom_content_file", value)

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Input[str]:
        """
        The Logging Analytics namespace used for the request.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: pulumi.Input[str]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter
    def expect(self) -> Optional[pulumi.Input[str]]:
        """
        A value of `100-continue` requests preliminary verification of the request method, path, and headers before the request body is sent. If no error results from such verification, the server will send a 100 (Continue) interim response to indicate readiness for the request body. The only allowed value for this parameter is "100-Continue" (case-insensitive).


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "expect")

    @expect.setter
    def expect(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "expect", value)

    @property
    @pulumi.getter(name="isOverwrite")
    def is_overwrite(self) -> Optional[pulumi.Input[bool]]:
        """
        A flag indicating whether or not to overwrite existing content if a conflict is found during import content operation.
        """
        return pulumi.get(self, "is_overwrite")

    @is_overwrite.setter
    def is_overwrite(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_overwrite", value)


@pulumi.input_type
class _LogAnalyticsImportCustomContentState:
    def __init__(__self__, *,
                 change_lists: Optional[pulumi.Input[Sequence[pulumi.Input['LogAnalyticsImportCustomContentChangeListArgs']]]] = None,
                 content_name: Optional[pulumi.Input[str]] = None,
                 expect: Optional[pulumi.Input[str]] = None,
                 field_names: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 import_custom_content_file: Optional[pulumi.Input[str]] = None,
                 is_overwrite: Optional[pulumi.Input[bool]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 parser_names: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 source_names: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering LogAnalyticsImportCustomContent resources.
        :param pulumi.Input[Sequence[pulumi.Input['LogAnalyticsImportCustomContentChangeListArgs']]] change_lists: LogAnalyticsImportCustomChangeList
        :param pulumi.Input[str] content_name: The content name.
        :param pulumi.Input[str] expect: A value of `100-continue` requests preliminary verification of the request method, path, and headers before the request body is sent. If no error results from such verification, the server will send a 100 (Continue) interim response to indicate readiness for the request body. The only allowed value for this parameter is "100-Continue" (case-insensitive).
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[Sequence[pulumi.Input[str]]] field_names: The field names.
        :param pulumi.Input[str] import_custom_content_file: Path to the file to upload which contains the custom content.
        :param pulumi.Input[bool] is_overwrite: A flag indicating whether or not to overwrite existing content if a conflict is found during import content operation.
        :param pulumi.Input[str] namespace: The Logging Analytics namespace used for the request.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] parser_names: The parser names.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] source_names: The source names.
        """
        if change_lists is not None:
            pulumi.set(__self__, "change_lists", change_lists)
        if content_name is not None:
            pulumi.set(__self__, "content_name", content_name)
        if expect is not None:
            pulumi.set(__self__, "expect", expect)
        if field_names is not None:
            pulumi.set(__self__, "field_names", field_names)
        if import_custom_content_file is not None:
            pulumi.set(__self__, "import_custom_content_file", import_custom_content_file)
        if is_overwrite is not None:
            pulumi.set(__self__, "is_overwrite", is_overwrite)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if parser_names is not None:
            pulumi.set(__self__, "parser_names", parser_names)
        if source_names is not None:
            pulumi.set(__self__, "source_names", source_names)

    @property
    @pulumi.getter(name="changeLists")
    def change_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['LogAnalyticsImportCustomContentChangeListArgs']]]]:
        """
        LogAnalyticsImportCustomChangeList
        """
        return pulumi.get(self, "change_lists")

    @change_lists.setter
    def change_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['LogAnalyticsImportCustomContentChangeListArgs']]]]):
        pulumi.set(self, "change_lists", value)

    @property
    @pulumi.getter(name="contentName")
    def content_name(self) -> Optional[pulumi.Input[str]]:
        """
        The content name.
        """
        return pulumi.get(self, "content_name")

    @content_name.setter
    def content_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "content_name", value)

    @property
    @pulumi.getter
    def expect(self) -> Optional[pulumi.Input[str]]:
        """
        A value of `100-continue` requests preliminary verification of the request method, path, and headers before the request body is sent. If no error results from such verification, the server will send a 100 (Continue) interim response to indicate readiness for the request body. The only allowed value for this parameter is "100-Continue" (case-insensitive).


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "expect")

    @expect.setter
    def expect(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "expect", value)

    @property
    @pulumi.getter(name="fieldNames")
    def field_names(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The field names.
        """
        return pulumi.get(self, "field_names")

    @field_names.setter
    def field_names(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "field_names", value)

    @property
    @pulumi.getter(name="importCustomContentFile")
    def import_custom_content_file(self) -> Optional[pulumi.Input[str]]:
        """
        Path to the file to upload which contains the custom content.
        """
        return pulumi.get(self, "import_custom_content_file")

    @import_custom_content_file.setter
    def import_custom_content_file(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "import_custom_content_file", value)

    @property
    @pulumi.getter(name="isOverwrite")
    def is_overwrite(self) -> Optional[pulumi.Input[bool]]:
        """
        A flag indicating whether or not to overwrite existing content if a conflict is found during import content operation.
        """
        return pulumi.get(self, "is_overwrite")

    @is_overwrite.setter
    def is_overwrite(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_overwrite", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The Logging Analytics namespace used for the request.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="parserNames")
    def parser_names(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The parser names.
        """
        return pulumi.get(self, "parser_names")

    @parser_names.setter
    def parser_names(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "parser_names", value)

    @property
    @pulumi.getter(name="sourceNames")
    def source_names(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The source names.
        """
        return pulumi.get(self, "source_names")

    @source_names.setter
    def source_names(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "source_names", value)


class LogAnalyticsImportCustomContent(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 expect: Optional[pulumi.Input[str]] = None,
                 import_custom_content_file: Optional[pulumi.Input[str]] = None,
                 is_overwrite: Optional[pulumi.Input[bool]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        This resource provides the Log Analytics Import Custom Content resource in Oracle Cloud Infrastructure Log Analytics service.

        Imports the specified custom content from the input in zip format.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_log_analytics_import_custom_content = oci.log_analytics.LogAnalyticsImportCustomContent("testLogAnalyticsImportCustomContent",
            import_custom_content_file=var["log_analytics_import_custom_content_import_custom_content_file"],
            namespace=var["log_analytics_import_custom_content_namespace"],
            expect=var["log_analytics_import_custom_content_expect"],
            is_overwrite=var["log_analytics_import_custom_content_is_overwrite"])
        ```

        ## Import

        Import is not supported for LogAnalyticsImportCustomContent

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] expect: A value of `100-continue` requests preliminary verification of the request method, path, and headers before the request body is sent. If no error results from such verification, the server will send a 100 (Continue) interim response to indicate readiness for the request body. The only allowed value for this parameter is "100-Continue" (case-insensitive).
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] import_custom_content_file: Path to the file to upload which contains the custom content.
        :param pulumi.Input[bool] is_overwrite: A flag indicating whether or not to overwrite existing content if a conflict is found during import content operation.
        :param pulumi.Input[str] namespace: The Logging Analytics namespace used for the request.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: LogAnalyticsImportCustomContentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the Log Analytics Import Custom Content resource in Oracle Cloud Infrastructure Log Analytics service.

        Imports the specified custom content from the input in zip format.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_log_analytics_import_custom_content = oci.log_analytics.LogAnalyticsImportCustomContent("testLogAnalyticsImportCustomContent",
            import_custom_content_file=var["log_analytics_import_custom_content_import_custom_content_file"],
            namespace=var["log_analytics_import_custom_content_namespace"],
            expect=var["log_analytics_import_custom_content_expect"],
            is_overwrite=var["log_analytics_import_custom_content_is_overwrite"])
        ```

        ## Import

        Import is not supported for LogAnalyticsImportCustomContent

        :param str resource_name: The name of the resource.
        :param LogAnalyticsImportCustomContentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(LogAnalyticsImportCustomContentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 expect: Optional[pulumi.Input[str]] = None,
                 import_custom_content_file: Optional[pulumi.Input[str]] = None,
                 is_overwrite: Optional[pulumi.Input[bool]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = LogAnalyticsImportCustomContentArgs.__new__(LogAnalyticsImportCustomContentArgs)

            __props__.__dict__["expect"] = expect
            if import_custom_content_file is None and not opts.urn:
                raise TypeError("Missing required property 'import_custom_content_file'")
            __props__.__dict__["import_custom_content_file"] = import_custom_content_file
            __props__.__dict__["is_overwrite"] = is_overwrite
            if namespace is None and not opts.urn:
                raise TypeError("Missing required property 'namespace'")
            __props__.__dict__["namespace"] = namespace
            __props__.__dict__["change_lists"] = None
            __props__.__dict__["content_name"] = None
            __props__.__dict__["field_names"] = None
            __props__.__dict__["parser_names"] = None
            __props__.__dict__["source_names"] = None
        super(LogAnalyticsImportCustomContent, __self__).__init__(
            'oci:LogAnalytics/logAnalyticsImportCustomContent:LogAnalyticsImportCustomContent',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            change_lists: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LogAnalyticsImportCustomContentChangeListArgs']]]]] = None,
            content_name: Optional[pulumi.Input[str]] = None,
            expect: Optional[pulumi.Input[str]] = None,
            field_names: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            import_custom_content_file: Optional[pulumi.Input[str]] = None,
            is_overwrite: Optional[pulumi.Input[bool]] = None,
            namespace: Optional[pulumi.Input[str]] = None,
            parser_names: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            source_names: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None) -> 'LogAnalyticsImportCustomContent':
        """
        Get an existing LogAnalyticsImportCustomContent resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LogAnalyticsImportCustomContentChangeListArgs']]]] change_lists: LogAnalyticsImportCustomChangeList
        :param pulumi.Input[str] content_name: The content name.
        :param pulumi.Input[str] expect: A value of `100-continue` requests preliminary verification of the request method, path, and headers before the request body is sent. If no error results from such verification, the server will send a 100 (Continue) interim response to indicate readiness for the request body. The only allowed value for this parameter is "100-Continue" (case-insensitive).
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[Sequence[pulumi.Input[str]]] field_names: The field names.
        :param pulumi.Input[str] import_custom_content_file: Path to the file to upload which contains the custom content.
        :param pulumi.Input[bool] is_overwrite: A flag indicating whether or not to overwrite existing content if a conflict is found during import content operation.
        :param pulumi.Input[str] namespace: The Logging Analytics namespace used for the request.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] parser_names: The parser names.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] source_names: The source names.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _LogAnalyticsImportCustomContentState.__new__(_LogAnalyticsImportCustomContentState)

        __props__.__dict__["change_lists"] = change_lists
        __props__.__dict__["content_name"] = content_name
        __props__.__dict__["expect"] = expect
        __props__.__dict__["field_names"] = field_names
        __props__.__dict__["import_custom_content_file"] = import_custom_content_file
        __props__.__dict__["is_overwrite"] = is_overwrite
        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["parser_names"] = parser_names
        __props__.__dict__["source_names"] = source_names
        return LogAnalyticsImportCustomContent(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="changeLists")
    def change_lists(self) -> pulumi.Output[Sequence['outputs.LogAnalyticsImportCustomContentChangeList']]:
        """
        LogAnalyticsImportCustomChangeList
        """
        return pulumi.get(self, "change_lists")

    @property
    @pulumi.getter(name="contentName")
    def content_name(self) -> pulumi.Output[str]:
        """
        The content name.
        """
        return pulumi.get(self, "content_name")

    @property
    @pulumi.getter
    def expect(self) -> pulumi.Output[str]:
        """
        A value of `100-continue` requests preliminary verification of the request method, path, and headers before the request body is sent. If no error results from such verification, the server will send a 100 (Continue) interim response to indicate readiness for the request body. The only allowed value for this parameter is "100-Continue" (case-insensitive).


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "expect")

    @property
    @pulumi.getter(name="fieldNames")
    def field_names(self) -> pulumi.Output[Sequence[str]]:
        """
        The field names.
        """
        return pulumi.get(self, "field_names")

    @property
    @pulumi.getter(name="importCustomContentFile")
    def import_custom_content_file(self) -> pulumi.Output[str]:
        """
        Path to the file to upload which contains the custom content.
        """
        return pulumi.get(self, "import_custom_content_file")

    @property
    @pulumi.getter(name="isOverwrite")
    def is_overwrite(self) -> pulumi.Output[bool]:
        """
        A flag indicating whether or not to overwrite existing content if a conflict is found during import content operation.
        """
        return pulumi.get(self, "is_overwrite")

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[str]:
        """
        The Logging Analytics namespace used for the request.
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter(name="parserNames")
    def parser_names(self) -> pulumi.Output[Sequence[str]]:
        """
        The parser names.
        """
        return pulumi.get(self, "parser_names")

    @property
    @pulumi.getter(name="sourceNames")
    def source_names(self) -> pulumi.Output[Sequence[str]]:
        """
        The source names.
        """
        return pulumi.get(self, "source_names")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DefaultSecurityListArgs', 'DefaultSecurityList']

@pulumi.input_type
class DefaultSecurityListArgs:
    def __init__(__self__, *,
                 manage_default_resource_id: pulumi.Input[str],
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 egress_security_rules: Optional[pulumi.Input[Sequence[pulumi.Input['DefaultSecurityListEgressSecurityRuleArgs']]]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 ingress_security_rules: Optional[pulumi.Input[Sequence[pulumi.Input['DefaultSecurityListIngressSecurityRuleArgs']]]] = None):
        """
        The set of arguments for constructing a DefaultSecurityList resource.
        """
        pulumi.set(__self__, "manage_default_resource_id", manage_default_resource_id)
        if compartment_id is not None:
            pulumi.set(__self__, "compartment_id", compartment_id)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if egress_security_rules is not None:
            pulumi.set(__self__, "egress_security_rules", egress_security_rules)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)
        if ingress_security_rules is not None:
            pulumi.set(__self__, "ingress_security_rules", ingress_security_rules)

    @property
    @pulumi.getter(name="manageDefaultResourceId")
    def manage_default_resource_id(self) -> pulumi.Input[str]:
        return pulumi.get(self, "manage_default_resource_id")

    @manage_default_resource_id.setter
    def manage_default_resource_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "manage_default_resource_id", value)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="egressSecurityRules")
    def egress_security_rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DefaultSecurityListEgressSecurityRuleArgs']]]]:
        return pulumi.get(self, "egress_security_rules")

    @egress_security_rules.setter
    def egress_security_rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DefaultSecurityListEgressSecurityRuleArgs']]]]):
        pulumi.set(self, "egress_security_rules", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)

    @property
    @pulumi.getter(name="ingressSecurityRules")
    def ingress_security_rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DefaultSecurityListIngressSecurityRuleArgs']]]]:
        return pulumi.get(self, "ingress_security_rules")

    @ingress_security_rules.setter
    def ingress_security_rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DefaultSecurityListIngressSecurityRuleArgs']]]]):
        pulumi.set(self, "ingress_security_rules", value)


@pulumi.input_type
class _DefaultSecurityListState:
    def __init__(__self__, *,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 egress_security_rules: Optional[pulumi.Input[Sequence[pulumi.Input['DefaultSecurityListEgressSecurityRuleArgs']]]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 ingress_security_rules: Optional[pulumi.Input[Sequence[pulumi.Input['DefaultSecurityListIngressSecurityRuleArgs']]]] = None,
                 manage_default_resource_id: Optional[pulumi.Input[str]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 time_created: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering DefaultSecurityList resources.
        """
        if compartment_id is not None:
            pulumi.set(__self__, "compartment_id", compartment_id)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if egress_security_rules is not None:
            pulumi.set(__self__, "egress_security_rules", egress_security_rules)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)
        if ingress_security_rules is not None:
            pulumi.set(__self__, "ingress_security_rules", ingress_security_rules)
        if manage_default_resource_id is not None:
            pulumi.set(__self__, "manage_default_resource_id", manage_default_resource_id)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if time_created is not None:
            pulumi.set(__self__, "time_created", time_created)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="egressSecurityRules")
    def egress_security_rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DefaultSecurityListEgressSecurityRuleArgs']]]]:
        return pulumi.get(self, "egress_security_rules")

    @egress_security_rules.setter
    def egress_security_rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DefaultSecurityListEgressSecurityRuleArgs']]]]):
        pulumi.set(self, "egress_security_rules", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)

    @property
    @pulumi.getter(name="ingressSecurityRules")
    def ingress_security_rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DefaultSecurityListIngressSecurityRuleArgs']]]]:
        return pulumi.get(self, "ingress_security_rules")

    @ingress_security_rules.setter
    def ingress_security_rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DefaultSecurityListIngressSecurityRuleArgs']]]]):
        pulumi.set(self, "ingress_security_rules", value)

    @property
    @pulumi.getter(name="manageDefaultResourceId")
    def manage_default_resource_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "manage_default_resource_id")

    @manage_default_resource_id.setter
    def manage_default_resource_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "manage_default_resource_id", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "time_created")

    @time_created.setter
    def time_created(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_created", value)


class DefaultSecurityList(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 egress_security_rules: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DefaultSecurityListEgressSecurityRuleArgs']]]]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 ingress_security_rules: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DefaultSecurityListIngressSecurityRuleArgs']]]]] = None,
                 manage_default_resource_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Create a DefaultSecurityList resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DefaultSecurityListArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a DefaultSecurityList resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param DefaultSecurityListArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DefaultSecurityListArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 egress_security_rules: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DefaultSecurityListEgressSecurityRuleArgs']]]]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 ingress_security_rules: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DefaultSecurityListIngressSecurityRuleArgs']]]]] = None,
                 manage_default_resource_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DefaultSecurityListArgs.__new__(DefaultSecurityListArgs)

            __props__.__dict__["compartment_id"] = compartment_id
            __props__.__dict__["defined_tags"] = defined_tags
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["egress_security_rules"] = egress_security_rules
            __props__.__dict__["freeform_tags"] = freeform_tags
            __props__.__dict__["ingress_security_rules"] = ingress_security_rules
            if manage_default_resource_id is None and not opts.urn:
                raise TypeError("Missing required property 'manage_default_resource_id'")
            __props__.__dict__["manage_default_resource_id"] = manage_default_resource_id
            __props__.__dict__["state"] = None
            __props__.__dict__["time_created"] = None
        super(DefaultSecurityList, __self__).__init__(
            'oci:Core/defaultSecurityList:DefaultSecurityList',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            compartment_id: Optional[pulumi.Input[str]] = None,
            defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            display_name: Optional[pulumi.Input[str]] = None,
            egress_security_rules: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DefaultSecurityListEgressSecurityRuleArgs']]]]] = None,
            freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            ingress_security_rules: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DefaultSecurityListIngressSecurityRuleArgs']]]]] = None,
            manage_default_resource_id: Optional[pulumi.Input[str]] = None,
            state: Optional[pulumi.Input[str]] = None,
            time_created: Optional[pulumi.Input[str]] = None) -> 'DefaultSecurityList':
        """
        Get an existing DefaultSecurityList resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DefaultSecurityListState.__new__(_DefaultSecurityListState)

        __props__.__dict__["compartment_id"] = compartment_id
        __props__.__dict__["defined_tags"] = defined_tags
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["egress_security_rules"] = egress_security_rules
        __props__.__dict__["freeform_tags"] = freeform_tags
        __props__.__dict__["ingress_security_rules"] = ingress_security_rules
        __props__.__dict__["manage_default_resource_id"] = manage_default_resource_id
        __props__.__dict__["state"] = state
        __props__.__dict__["time_created"] = time_created
        return DefaultSecurityList(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Output[str]:
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[str]:
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="egressSecurityRules")
    def egress_security_rules(self) -> pulumi.Output[Optional[Sequence['outputs.DefaultSecurityListEgressSecurityRule']]]:
        return pulumi.get(self, "egress_security_rules")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter(name="ingressSecurityRules")
    def ingress_security_rules(self) -> pulumi.Output[Optional[Sequence['outputs.DefaultSecurityListIngressSecurityRule']]]:
        return pulumi.get(self, "ingress_security_rules")

    @property
    @pulumi.getter(name="manageDefaultResourceId")
    def manage_default_resource_id(self) -> pulumi.Output[str]:
        return pulumi.get(self, "manage_default_resource_id")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[str]:
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> pulumi.Output[str]:
        return pulumi.get(self, "time_created")

